@@ -36,7 +36,7 @@ import java.util.zip.Inflater;
  * <p/>
  * It uses &lt;segment&gt;.fdt and &lt;segment&gt;.fdx; files.
  *
- * @version $Id: FieldsReader.java 695184 2008-09-14 10:32:59Z mikemccand $
+ * @version $Id: FieldsReader.java 713970 2008-11-14 10:29:11Z mikemccand $
  */
 final class FieldsReader {
   private final FieldInfos fieldInfos;
@@ -423,6 +423,8 @@ final class FieldsReader {
       this.toRead = toRead;
       this.pointer = pointer;
       this.isBinary = isBinary;
+      if (isBinary)
+        binaryLength = toRead;
       lazy = true;
     }
 
@@ -431,6 +433,8 @@ final class FieldsReader {
       this.toRead = toRead;
       this.pointer = pointer;
       this.isBinary = isBinary;
+      if (isBinary)
+        binaryLength = toRead;
       lazy = true;
     }
 
@@ -619,6 +623,9 @@ final class FieldsReader {
       this.fieldsData = value;
       this.isCompressed = compressed;
       this.isBinary = binary;
+      if (binary)
+        binaryLength = ((byte[]) value).length;
+
       this.isTokenized = tokenize;
 
       this.name = fi.name.intern();
